#Altoshift Module Python#

Altoshift.com - Search engine as a service.

we provide easy setup for integration.

## Installing

```
pip install altoshift --user
```

## Upgrade

```
pip install altoshift --upgrade --user
```



Author :
Eko Aprili Trisno

eaprilitrisno@gmail.com
